@@ -22,11 +22,11 @@ public:
 
     /* reimpl */
     Pop3ResourceAttribute *clone() const override;
-    QByteArray type() const override;
-    QByteArray serialized() const override;
+    [[nodiscard]] QByteArray type() const override;
+    [[nodiscard]] QByteArray serialized() const override;
     void deserialize(const QByteArray &data) override;
 
-    QString pop3AccountName() const;
+    [[nodiscard]] QString pop3AccountName() const;
     void setPop3AccountName(const QString &accountName);
 
     bool operator==(const Pop3ResourceAttribute &other) const;
