@@ -15,10 +15,6 @@
 #include <Akonadi/SpecialCollectionAttribute>
 
 #include <KLocalizedString>
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 using namespace Akonadi;
 
@@ -67,11 +63,6 @@ SpecialMailCollectionsPrivate::~SpecialMailCollectionsPrivate()
 
 static KCoreConfigSkeleton *getConfig(const QString &filename)
 {
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("specialmailcollection"));
-    migrate.setConfigFiles(QStringList() << filename);
-    migrate.migrate();
-#endif
     Settings::instance(ServerManager::addNamespace(filename));
     return Settings::self();
 }
@@ -175,3 +166,5 @@ SpecialMailCollections::Type SpecialMailCollections::specialCollectionType(const
         return typeToEnum(collection.attribute<SpecialCollectionAttribute>()->collectionType());
     }
 }
+
+#include "moc_specialmailcollections.cpp"
